@@ -1,11 +1,8 @@
 package Sys::Info::Driver::Windows;
 use strict;
-use warnings;
-
-our $VERSION = '0.75_02';
-
-use base qw( Exporter );
-use Carp qw( croak    );
+use vars qw( $VERSION @ISA @EXPORT %EXPORT_TAGS @EXPORT_OK );
+use Exporter ();
+use Carp qw( croak );
 use Sys::Info::Constants qw( WIN_B24_DIGITS );
 
 # (only relevant) indexes for GetSystemMetrics()
@@ -13,33 +10,14 @@ use constant SM_TABLETPC    => 86; # Windows XP Tablet PC edition
 use constant SM_MEDIACENTER => 87; # Windows XP, Media Center Edition
 use constant SM_STARTER     => 88; # Windows XP Starter Edition
 use constant SM_SERVERR2    => 89; # Windows Server 2003 R2
-use constant SERIAL_BASE    => 24;
 
+use Exporter ();
 use XSLoader;
 
-my %REGISTRY;
-BEGIN {
-    # SetDualVar req. in Win32::TieRegistry breaks any handler
-    local $SIG{__DIE__};
-    local $@;
-
-    my $eok = eval {
-        require Win32::TieRegistry;
-        Win32::TieRegistry->import(
-            TiedHash  => \%REGISTRY,
-            Delimiter => q{/},
-        );
-        1;
-    };
-
-    if ( $@ || ! $eok ) {
-        my $error = $@ || '<unknown error>';
-        croak "Error loading Win32::TieRegistry: $error";
-    }
-}
-
-our @EXPORT;
-our %EXPORT_TAGS = (
+$VERSION = '0.70';
+@ISA     = qw( Exporter );
+@EXPORT  = qw(  );
+%EXPORT_TAGS = (
     metrics => [qw/
         GetSystemMetrics
         SM_TABLETPC
@@ -47,27 +25,26 @@ our %EXPORT_TAGS = (
         SM_SERVERR2
         SM_STARTER
     /],
-    info => [ qw/ GetSystemInfo CPUFeatures / ],
-    WMI  => [ qw/ WMI WMI_FOR               / ],
-    etc  => [ qw/ decode_serial_key         / ],
-    reg  => [ qw/ registry                  / ],
+    info => [qw/
+        GetSystemInfo
+    /],
+    WMI => [qw/ WMI WMI_FOR /],
+    etc => [qw/decode_serial_key/],
 );
-our @EXPORT_OK    = map { @{ $EXPORT_TAGS{$_} } } keys %EXPORT_TAGS;
+@EXPORT_OK        = map { @{ $EXPORT_TAGS{$_} } } keys %EXPORT_TAGS;
 $EXPORT_TAGS{all} = \@EXPORT_OK;
 
 XSLoader::load( __PACKAGE__, $VERSION );
 
-sub registry { return \%REGISTRY }
-
 sub WMI {
-    my $WMI = Win32::OLE->GetObject( 'WinMgmts:' ) || return;
-    croak Win32::OLE->LastError if Win32::OLE->LastError != 0;
+    my $WMI = Win32::OLE->GetObject("WinMgmts:") || return; 
+    croak Win32::OLE->LastError() if Win32::OLE->LastError() != 0;
     return $WMI;
 }
 
 sub WMI_FOR {
     my $WMI = WMI() || return;
-    my $ID  = shift || croak 'No WMI Class specified';
+    my $ID  = shift || die "No WMI Class specified";
     my $O   = $WMI->InstancesOf( $ID ) || return;
     croak Win32::OLE->LastError() if Win32::OLE->LastError() != 0;
     return $O;
@@ -78,8 +55,7 @@ sub decode_serial_key {
     #     http://www.perlmonks.org/?node_id=497616
     #     (c) Original code: William Gannon
     #     (c) Modifications: Charles Clarkson
-    ## no critic (ValuesAndExpressions::ProhibitMagicNumbers)
-    my $key     = shift || croak 'Key is missing';
+    my $key     = shift || die "Key is missing";
     my @encoded = ( unpack 'C*', $key )[ reverse 52 .. 66 ];
     use integer;
 
@@ -87,11 +63,11 @@ sub decode_serial_key {
         my( $index, $encoded ) = @_;
         my $dividend = $index * 256 ^ $encoded;
         # return modulus and integer quotient
-        return( $dividend % SERIAL_BASE, $dividend / SERIAL_BASE );
+        return( $dividend % 24, $dividend / 24 );
     };
 
     my @indices;
-    foreach my $i ( 0 .. SERIAL_BASE ) {
+    foreach my $i ( 0 .. 24 ) {
         my $index = 0;
         foreach my $j (@encoded) { # Shift off remainder
             ( $index, $j ) = $quotient->( $index, $j );
@@ -100,38 +76,29 @@ sub decode_serial_key {
     }
 
     # translate base 24 "digits" to characters
-    my $cd_key = join q{}, (WIN_B24_DIGITS)[ @indices ];
+    my $cd_key = join '', (WIN_B24_DIGITS)[ @indices ];
 
     # Add seperators and return
-    return join q{-}, $cd_key =~ m/(.{5})/xmsg;
+    return join '-', $cd_key =~ /(.{5})/g;
 }
 
 1;
 
 __END__
 
-=pod
-
 =head1 NAME
 
 Sys::Info::Driver::Windows - Windows driver for Sys::Info
 
 =head1 SYNOPSIS
 
-    use Sys::Info::Driver::Windows qw(:metrics);
+    use Sys::Info::Driver::Windows::XS qw(:metrics);
     if ( GetSystemMetrics(SM_SERVERR2) ) {
         # do something ...
     }
 
 =head1 DESCRIPTION
 
-This document describes version C<0.75_02> of C<Sys::Info::Driver::Windows>
-released on C<16 July 2010>.
-
-B<WARNING>: This version of the module is part of a
-developer (beta) release of the distribution and it is
-not suitable for production use.
-
 This is the main module in the C<Windows> driver collection.
 
 =head1 METHODS
@@ -143,14 +110,6 @@ None.
 The following functions will be automatically exported when the module
 is used.
 
-=head2 CPUFeatures
-
-TODO
-
-=head2 registry
-
-Returns a C<Win32::TieRegistry> hashref.
-
 =head2 WMI
 
 Returns the C<WMI> object.
@@ -200,16 +159,16 @@ L<http://msdn.microsoft.com/en-us/library/ms724429(VS.85).aspx>.
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>.
+Burak Grsoy, E<lt>burakE<64>cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2006 - 2010 Burak Gursoy. All rights reserved.
+Copyright 2006-2009 Burak Grsoy. All rights reserved.
 
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.12.1 or, 
+it under the same terms as Perl itself, either Perl version 5.10.0 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
