@@ -1,15 +1,13 @@
 package Sys::Info::Driver::Windows::Device;
 use strict;
-use warnings;
+use vars qw( $VERSION );
 
-our $VERSION = '0.75_02';
+$VERSION = '0.70';
 
 1;
 
 __END__
 
-=pod
-
 =head1 NAME
 
 Sys::Info::Driver::Windows::Device - Base class for Windows device drivers
@@ -20,13 +18,6 @@ Sys::Info::Driver::Windows::Device - Base class for Windows device drivers
 
 =head1 DESCRIPTION
 
-This document describes version C<0.75_02> of C<Sys::Info::Driver::Windows::Device>
-released on C<16 July 2010>.
-
-B<WARNING>: This version of the module is part of a
-developer (beta) release of the distribution and it is
-not suitable for production use.
-
 Base class for Windows device drivers.
 
 =head1 METHODS
@@ -35,16 +26,16 @@ None.
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>.
+Burak Grsoy, E<lt>burakE<64>cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2006 - 2010 Burak Gursoy. All rights reserved.
+Copyright 2006-2009 Burak Grsoy. All rights reserved.
 
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.12.1 or, 
+it under the same terms as Perl itself, either Perl version 5.10.0 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
