@@ -1,20 +1,29 @@
 package Sys::Info::Driver::Windows::Device::CPU;
 use strict;
-use warnings;
-#use vars     qw( $Registry );
+use vars     qw( $VERSION @ISA $Registry );
 use base qw(
     Sys::Info::Driver::Unknown::Device::CPU::Env
     Sys::Info::Driver::Windows::Device::CPU::WMI
 );
-use Sys::Info::Constants       qw( :windows_reg    );
-use Sys::Info::Driver::Windows::Constants;
-use Sys::Info::Driver::Windows qw( :info :reg :WMI CPUFeatures );
-use Carp                       qw( croak           );
-use Win32::OLE                 qw( in              );
+use Sys::Info::Constants qw( :windows_reg );
+use Sys::Info::Driver::Windows qw( :info );
+use Carp qw( croak );
+
+$VERSION = '0.70';
 
-our $VERSION = '0.75_02';
 my $REG;
-$REG = registry()->{ +WIN_REG_CPU_KEY } if registry()->{ +WIN_REG_HW_KEY };
+TRY_TO_LOAD: {
+    # SetDualVar req. in Win32::TieRegistry breaks any handler
+    local $SIG{__DIE__};
+    local $@;
+    eval {
+        require Win32::TieRegistry;
+        Win32::TieRegistry->import(Delimiter => '/');
+    };
+    if ( ! $@ && defined $Registry->{+WIN_REG_HW_KEY} ) {
+        $REG = $Registry->{ +WIN_REG_CPU_KEY };
+    }
+}
 
 sub load {
     my $self = shift;
@@ -24,21 +33,8 @@ sub load {
 
 sub bitness {
     my $self = shift;
-    ## no critic (ValuesAndExpressions::ProhibitMagicNumbers)
-    # XXX: put this into ->arch()
-    if ( my($cpu) = $self->_from_wmi ) {
-        my $arch = $cpu->{architecture};
-        if ( $arch ) {
-            return +( $arch eq 'x64' || $arch =~ m{Itanium}xms ) ? 64 : 32;
-        }
-    }
     my %i    = GetSystemInfo();
-    my $bits = $i{wProcessorBitness};
-    if ( $bits < 0 ) {
-        warn "Failed to detect processor bitness. Guessing as 32bit\n";
-        return 32;
-    }
-    return $bits;
+    return $i{wProcessorBitness};
 }
 
 # XXX: interface is unclear. return data based on context !!!
@@ -47,11 +43,10 @@ sub bitness {
 sub identify {
     my $self = shift;
     if ( ! $self->{META_DATA} ) {
-        my @cache = $self->_from_wmi
+        my @cache = $self->_from_wmi 
                     or $self->_from_registry
                     or $self->SUPER::identify(@_)
-                    or croak('Failed to identify CPU');
-        $self->_set_flags( \@cache );
+                    or croak("Failed to identify CPU");
         $self->{META_DATA} = [ @cache ];
     }
     return $self->_serve_from_cache(wantarray);
@@ -59,48 +54,6 @@ sub identify {
 
 # ------------------------[ P R I V A T E ]------------------------ #
 
-sub _set_flags {
-    my($self, $cpu) = @_;
-
-    my %feat = CPUFeatures();
-    my $c    = 'Sys::Info::Driver::Windows::Constants';
-
-    my $get_symbols = sub {
-        # fetch the related constants
-        my $regex = shift || die "Regex missing\n";
-        no strict qw( refs );
-        return grep { $_ =~ $regex } keys %{ $c . q{::} };
-    };
-
-    my $cf = $feat{CpuFeatures};
-    my $f  = $feat{Flags};
-    my $k  = $feat{KFBits};
-    my $ff = $feat{FeatureFlags};
-    my @flags;
-
-    foreach my $flag ( $get_symbols->( qr{ \A CF_ }xms ) ){
-        push @flags, $flag if $f & $c->$flag();
-    }
-
-    foreach my $flag ( $get_symbols->( qr{ \A KF_ }xms ) ){
-        push @flags, $flag if $k & $c->$flag();
-    }
-
-    foreach my $flag ( $get_symbols->( qr{ \A FT_ }xms ) ){
-        push @flags, $flag if $ff & $c->$flag();
-    }
-
-    foreach my $e ( @flags ) {
-        $e =~ s{ \A (?: CF|KF|FT )_ }{}xms;
-    }
-
-    my %fbuf = map { lc $_ => 1 } @flags;
-    @flags = sort keys %fbuf;
-
-    $cpu->[$_]{flags} = [ @flags ] for 0..$#{$cpu};
-    return;
-}
-
 # $REG->{'0/FeatureSet'}
 # $REG->{'0/Update Status'}
 sub _from_registry {
@@ -146,8 +99,6 @@ sub __env_pi { # XXX: remove this thing
 
 __END__
 
-=pod
-
 =head1 NAME
 
 Sys::Info::Driver::Windows::Device::CPU - Windows CPU Device Driver
@@ -158,13 +109,6 @@ Sys::Info::Driver::Windows::Device::CPU - Windows CPU Device Driver
 
 =head1 DESCRIPTION
 
-This document describes version C<0.75_02> of C<Sys::Info::Driver::Windows::Device::CPU>
-released on C<16 July 2010>.
-
-B<WARNING>: This version of the module is part of a
-developer (beta) release of the distribution and it is
-not suitable for production use.
-
 Uses C<WMI>, C<Registry> and C<ENV> to identify the CPU.
 
 =head1 METHODS
@@ -188,16 +132,16 @@ L<Sys::Info::Device::CPU>.
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>.
+Burak Grsoy, E<lt>burakE<64>cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2006 - 2010 Burak Gursoy. All rights reserved.
+Copyright 2006-2009 Burak Grsoy. All rights reserved.
 
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.12.1 or, 
+it under the same terms as Perl itself, either Perl version 5.10.0 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
