@@ -1,22 +1,25 @@
 package Sys::Info::Driver::Windows::OS;
 use strict;
-use warnings;
+use vars qw( $VERSION );
 
-our $VERSION = '0.75_02';
+$VERSION = '0.70';
 
-## no critic (ValuesAndExpressions::ProhibitMagicNumbers)
-## no critic (ValuesAndExpressions::RequireNumberSeparators)
-
-use constant LAST_ELEMENT => -1;
-use constant MILISECOND   => 1000;
 use base qw( Sys::Info::Driver::Windows::OS::Editions );
 use Win32;
-use Win32::OLE                 qw( in    );
-use Carp                       qw( croak );
-use Sys::Info::Driver::Windows qw( :all  );
+use Win32::OLE qw( in );
+use Sys::Info::Driver::Windows qw( :all );
 use Sys::Info::Driver::Windows::OS::Net;
-
-use Sys::Info::Constants qw( :windows_reg :windows_wmi NEW_PERL );
+use Carp qw( croak );
+BEGIN {
+    # SetDualVar req. in Win32::TieRegistry breaks any handler
+    local $SIG{__DIE__};
+    eval {
+        require Win32::TieRegistry;
+        Win32::TieRegistry->import( Delimiter => '/' );
+    };
+    die $@ if $@;
+}
+use Sys::Info::Constants qw( :windows_reg :windows_wmi );
 
 # first row -> All; second row -> NT 4 SP6 and later
 my @OSV_NAMES = qw/
@@ -24,16 +27,12 @@ my @OSV_NAMES = qw/
     SPMAJOR SPMINOR SUITEMASK PRODUCTTYPE
 /;
 
-BEGIN {
-    *is_win9x = *is_win95 = sub{ Win32::IsWin95() } if ! defined &is_win9x;
-    *is_winnt             = sub{ Win32::IsWinNT() } if ! defined &is_winnt;
-}
+my %OSVERSION;  # see _populate_osversion
+my %FILESYSTEM; # see _populate_fs
 
-sub init {
-    my $self = shift;
-    $self->{OSVERSION}  = undef; # see _populate_osversion
-    $self->{FILESYSTEM} = undef; # see _populate_fs
-    return;
+BEGIN {
+    *is_win9x = *is_win95 = sub{ Win32::IsWin95() } if not defined &is_win9x;
+    *is_winnt             = sub{ Win32::IsWinNT() } if not defined &is_winnt;
 }
 
 sub is_root {
@@ -44,44 +43,47 @@ sub is_root {
          ;
 }
 
-sub node_name { return Win32::NodeName() }
+sub node_name { Win32::NodeName() }
 
 sub edition {
-    return shift->_populate_osversion->{OSVERSION}{RAW}{EDITION};
+    my $self = shift->_populate_osversion;
+    $OSVERSION{RAW}->{EDITION};
 }
 
 sub product_type {
-    my($self, @args) = @_;
-    $self->_populate_osversion;
-    my %opt  = @args % 2 ? () : @args;
-    my $raw  = $self->{OSVERSION}{RAW}{PRODUCTTYPE};
-    return $opt{raw} ? $raw : $self->_product_type( $raw );
+    my $self = shift->_populate_osversion;
+    my %opt  = @_ % 2 ? () : (@_);
+    my $raw  = $OSVERSION{RAW}->{PRODUCTTYPE};
+    return $raw if $opt{raw};
+    return $self->_product_type( $raw );
 }
 
 sub name {
-    my($self, @args) = @_;
-    $self->_populate_osversion;
-    my %opt  = @args % 2  ? ()         : @args;
-    my $id   = $opt{long} ? 'LONGNAME' : 'NAME';
-    return $self->{OSVERSION}{ $opt{edition} ? $id . '_EDITION' : $id };
+    my $self = shift->_populate_osversion;
+    my %opt  = @_ % 2 ? () : (@_);
+    my $id   = $opt{long} ? ($opt{edition} ? 'LONGNAME_EDITION' : 'LONGNAME')
+             :              ($opt{edition} ? 'NAME_EDITION'     : 'NAME'    )
+             ;
+    return $OSVERSION{ $id };
 }
 
 sub version {
-    my($self, @args) = @_;
-    my %opt     = @args % 2 ? () : @args;
-    my $version = $self->_populate_osversion->{OSVERSION}{VERSION};
+    my $self    = shift->_populate_osversion;
+    my %opt     = @_ % 2 ? () : (@_);
+    my $version = $OSVERSION{VERSION};
 
     if ( $opt{short} ) {
-        my @v = split m{[.]}xms, $version;
-        shift @v;
-        return join q{.}, @v ;
+        my @v = split /\./, $version;
+        shift(@v);
+        return join( '.', @v );
     }
 
     return $version;
 }
 
 sub build {
-    return shift->_populate_osversion->{OSVERSION}{RAW}{BUILD} || 0;
+    my $self = shift->_populate_osversion;
+    return $OSVERSION{RAW}->{BUILD} || 0;
 }
 
 sub uptime {
@@ -91,19 +93,18 @@ sub uptime {
 
 sub domain_name {
     my $self = shift;
-    return $self->is_win95() ? q{} : Win32::DomainName()
+    return $self->is_win95() ? '' : Win32::DomainName()
 }
 
 sub tick_count {
     my $self = shift;
     my $tick = Win32::GetTickCount();
-    return $tick ? $tick / MILISECOND : 0; # in miliseconds
+    return $tick ? $tick / 1000 : 0; # in miliseconds
 }
 
 sub login_name {
-    my($self, @args) = @_;
-    $self->_populate_osversion;
-    my %opt   = @args % 2 ? () : @args;
+    my $self  = shift;
+    my %opt   = @_ % 2 ? () : (@_);
     my $login = Win32::LoginName();
     return $opt{real} && $login
            ? Sys::Info::Driver::Windows::OS::Net->user_fullname( $login )
@@ -113,29 +114,21 @@ sub login_name {
 
 sub logon_server {
     my $self = shift;
-    my $name = $self->login_name || return q{};
+    my $name = $self->login_name || return '';
     return Sys::Info::Driver::Windows::OS::Net->user_logon_server( $name );
 }
 
 sub fs {
     my $self = shift;
-    return %{ $self->_populate_fs->{FILESYSTEM} };
+    $self->_populate_fs();
+    return %FILESYSTEM;
 }
 
 sub tz {
     my $self = shift;
-    my $tz;
-    foreach my $object ( in WMI_FOR('Win32_TimeZone') ) {
-        $tz = $object->Caption;
-        last;
+    foreach my $objItem ( in WMI_FOR('Win32_TimeZone') ) {
+        return $objItem->Caption;
     }
-    if ( NEW_PERL ) {
-        require Encode;
-        my $locale = $self->locale;
-        my $cp     = (split m{[.]}xms, $locale)[LAST_ELEMENT] + 0; # vugly hack
-        $tz = Encode::decode( "cp$cp", $tz ) if $cp;
-    }
-    return $tz;
 }
 
 sub meta {
@@ -170,22 +163,22 @@ sub meta {
 }
 
 sub cdkey {
-    my($self, @args) = @_;
     return if Win32::IsWin95(); # not supported
-    my %opt = @args % 2 ? () : @args;
+    my $self = shift;
+    my %opt  = @_ % 2 ? () : (@_);
 
     if ( $opt{office} ) {
-        my $base = registry()->{ +WIN_REG_OCDKEY };
+        my $base = $Registry->{ +WIN_REG_OCDKEY };
         my @versions;
         foreach my $e ( keys %{ $base } ) {
-            next if $e =~ m{[^0-9\./]}xms; # only get versioned keys
+            next if $e =~ m{[^0-9\./]}; # only get versioned keys
             $e =~ s{ / \z }{}xms;
             # check all installed office versions
             push @versions, $e if $base->{ $e . '/Registration' };
         }
 
         my @list;
-        foreach my $v ( reverse sort { $a <=> $b } @versions ) {
+        foreach my $v ( sort { $b <=> $a } @versions ) {
             my $key = $base->{ $v . '/Registration' };
             my $id  = ( keys %{ $key } )[0];
             my $val = $key->{ $id . 'DigitalProductId' } || next;
@@ -194,7 +187,7 @@ sub cdkey {
         return @list; #return all available keys
     }
 
-    my $val = registry()->{ +WIN_REG_CDKEY } || return;
+    my $val = $Registry->{ +WIN_REG_CDKEY } || return;
     return decode_serial_key( $val );
 }
 
@@ -209,46 +202,44 @@ sub bitness {
 sub _wmidate_to_unix {
     my $self  = shift;
     my $thing = shift || return;
-    my($date, $junk) = split m/[.]/xms, $thing;
+    my($date, $junk) = split /\./, $thing;
     my($year, $mon, $mday, $hour, $min, $sec) = unpack WIN_WMI_DATE_TMPL, $date;
     require Time::Local;
     return Time::Local::timelocal( $sec, $min, $hour, $mday, $mon-1, $year );
 }
 
 sub _populate_fs {
+    return if %FILESYSTEM;
     my $self  = shift;
-    return $self if $self->{FILESYSTEM};
     my($FSTYPE, $FLAGS, $MAXCOMPLEN) = Win32::FsType();
     if ( !$FSTYPE && Win32::GetLastError() ) {
-        warn "Can not fetch file system information: $^E\n";
+        warn "Can not fetch file system information: $^E";
         return;
     }
     my %flag = (
-        case_sensitive     => 0x00000001, #supports case-sensitive filenames
-        preserve_case      => 0x00000002, #preserves the case of filenames
-        unicode            => 0x00000004, #supports Unicode in filenames
-        acl                => 0x00000008, #preserves and enforces ACLs
-        file_compression   => 0x00000010, #supports file-based compression
-        disk_quotas        => 0x00000020, #supports disk quotas
-        sparse             => 0x00000040, #supports sparse files
-        reparse            => 0x00000080, #supports reparse points
-        remote_storage     => 0x00000100, #supports remote storage
-        compressed_volume  => 0x00008000, #is a compressed volume (e.g. DoubleSpace)
-        object_identifiers => 0x00010000, #supports object identifiers
-        efs                => 0x00020000, #supports the Encrypted File System (EFS)
+        case_sensitive     => 0x00000001,  #'supports case-sensitive filenames',
+        preserve_case      => 0x00000002,  #'preserves the case of filenames',
+        unicode            => 0x00000004,  #'supports Unicode in filenames',
+        acl                => 0x00000008,  #'preserves and enforces ACLs',
+        file_compression   => 0x00000010,  #'supports file-based compression',
+        disk_quotas        => 0x00000020,  #'supports disk quotas',
+        sparse             => 0x00000040,  #'supports sparse files',
+        reparse            => 0x00000080,  #'supports reparse points',
+        remote_storage     => 0x00000100,  #'supports remote storage',
+        compressed_volume  => 0x00008000,  #'is a compressed volume (e.g. DoubleSpace)',
+        object_identifiers => 0x00010000,  #'supports object identifiers',
+        efs                => 0x00020000,  #'supports the Encrypted File System (EFS)',
     );
     my @fl;
-    if ( $FLAGS ) {
+    if ($FLAGS) {
         foreach my $f (keys %flag) {
             push @fl, $f => $flag{$f} & $FLAGS ? 1 : 0;
         }
     }
-
     push @fl, max_file_length => $MAXCOMPLEN if $MAXCOMPLEN;
     push @fl, filesystem      => $FSTYPE     if $FSTYPE; # NTFS/FAT/FAT32
-
-    $self->{FILESYSTEM} = { @fl };
-    return $self;
+    %FILESYSTEM = (@fl);
+    return;
 }
 
 sub _osversion_table {
@@ -256,7 +247,7 @@ sub _osversion_table {
     my $OSV     = shift;
 
     my $t       = sub { $OSV->{MAJOR} == $_[0] && $OSV->{MINOR} == $_[1] };
-    my $version = join q{.}, $OSV->{ID}, $OSV->{MAJOR}, $OSV->{MINOR};
+    my $version = join '.', $OSV->{ID}, $OSV->{MAJOR}, $OSV->{MINOR};
     my $ID      = $OSV->{ID};
     my($os,$edition);
 
@@ -277,7 +268,6 @@ sub _osversion_table {
             : $t->(5,1) ? $self->_xp_editions( \$edition, \$os, $OSV )
             : $t->(5,2) ? $self->_xp_or_03(    \$edition, \$os, $OSV )
             : $t->(6,0) ? $self->_vista_or_08( \$edition, \$os       )
-            : $t->(6,1) ? $self->_win7(        \$edition, \$os       )
             :             do { $os = "Windows NT $version" }
         }
     }
@@ -290,7 +280,7 @@ sub _osversion_table {
 
 sub _populate_osversion { # returns the object
     my $self = shift;
-    return $self if $self->{OSVERSION};
+    return $self if %OSVERSION; # build once use everywhere :p
     # Win32::GetOSName() is not reliable.
     # Since, an older release will not have any idea about XP or Vista
     # Server 2008 is tricky since it has the same version number as Vista
@@ -302,11 +292,11 @@ sub _populate_osversion { # returns the object
 
     my($osname, $version, $edition) = $self->_osversion_table( \%OSV );
 
-    $self->{OSVERSION} = {
+    %OSVERSION = (
         NAME             => $osname,
-        NAME_EDITION     => $edition ? "$osname $edition" : $osname,
-        LONGNAME         => q{}, # will be set below
-        LONGNAME_EDITION => q{}, # will be set below
+        NAME_EDITION     => "$osname $edition",
+        LONGNAME         => '', # will be set below
+        LONGNAME_EDITION => '', # will be set below
         VERSION          => $version,
         RAW              => {
             STRING      => $OSV{STRING},
@@ -320,14 +310,13 @@ sub _populate_osversion { # returns the object
             EDITION     => $edition,
             SUITEMASK   => $OSV{SUITEMASK},
         },
-    };
+    );
 
-    my $o      = $self->{OSVERSION};
-    my $build  = $o->{RAW}{BUILD} ? 'build ' . $o->{RAW}{BUILD} : q{};
-    my $string = $o->{RAW}{STRING};
-
-    $o->{LONGNAME}         = join q{ }, $o->{NAME},         $string, $build;
-    $o->{LONGNAME_EDITION} = join q{ }, $o->{NAME_EDITION}, $string, $build;
+    my $build  = '';
+       $build .= "build $OSVERSION{RAW}->{BUILD}" if $OSVERSION{RAW}->{BUILD};
+    my $string = $OSVERSION{RAW}->{STRING};
+    $OSVERSION{LONGNAME}         = join ' ', $OSVERSION{NAME}, $string, $build;
+    $OSVERSION{LONGNAME_EDITION} = join ' ', $OSVERSION{NAME_EDITION}, $string, $build;
 
     return $self;
 }
@@ -357,13 +346,6 @@ This is a private sub-class.
 
 =head1 DESCRIPTION
 
-This document describes version C<0.75_02> of C<Sys::Info::Driver::Windows::OS>
-released on C<16 July 2010>.
-
-B<WARNING>: This version of the module is part of a
-developer (beta) release of the distribution and it is
-not suitable for production use.
-
 This document only discusses the driver specific parts.
 
 =head1 METHODS
@@ -380,8 +362,6 @@ This document only discusses the driver specific parts.
 
 =head2 fs
 
-=head2 init
-
 =head2 is_win95
 
 =head2 is_win9x
@@ -427,15 +407,14 @@ version values and corresponding names are:
    2.5.1     Windows XP
    2.5.2     Windows Server 2003
    2.6.0     Windows Vista
-   2.6.0     Windows Server 2008(*)
-   2.6.1     Windows 7(**)
+   2.6.0     Windows Server 2008*
 
 It is also possible to get the short version (C<5.1> instead of C<2.5.1> for XP)
 if you pass the C<short> parameter with a true value:
 
     my $v = $os->version( short => 1 );
 
-(*) Unfortunately Windows Server 2008 has the same version number as Vista.
+* Unfortunately Windows Server 2008 has the same version number as Vista.
 One needs to check the L<name> method to differentiate:
 
     if ( $os->version eq '2.6.0' ) {
@@ -450,9 +429,6 @@ One needs to check the L<name> method to differentiate:
         print "Old Technology";
     }
 
-(**) Yes, that is correct. "Windows 7" is B<not> Windows version 7. It's the
-marketing name.
-
 =head1 SEE ALSO
 
 L<Win32>, L<Sys::Info>, L<Sys::Info::OS>,
@@ -463,16 +439,16 @@ L<http://msdn.microsoft.com/en-us/library/ms724358(VS.85).aspx>
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>.
+Burak Gürsoy, E<lt>burakE<64>cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2006 - 2010 Burak Gursoy. All rights reserved.
+Copyright 2006-2009 Burak Gürsoy. All rights reserved.
 
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.12.1 or, 
+it under the same terms as Perl itself, either Perl version 5.10.0 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
